nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

SwPadCtlPadTestMode

Struct SwPadCtlPadTestMode 

#[repr(transparent)]
pub struct SwPadCtlPadTestMode(pub u32);
SW_PAD_CTL_PAD_TEST_MODE SW PAD Control Register

Tuple Fields

0: u32

Implementations

Source

impl SwPadCtlPadTestMode

pub const fn sre(&self) -> SwPadCtlPadTestModeSre

Slew Rate Field

pub const fn set_sre(&mut self, val: SwPadCtlPadTestModeSre)

Slew Rate Field

pub const fn dse(&self) -> SwPadCtlPadTestModeDse

Drive Strength Field

pub const fn set_dse(&mut self, val: SwPadCtlPadTestModeDse)

Drive Strength Field

pub const fn speed(&self) -> SwPadCtlPadTestModeSpeed

Speed Field

pub const fn set_speed(&mut self, val: SwPadCtlPadTestModeSpeed)

Speed Field

pub const fn ode(&self) -> SwPadCtlPadTestModeOde

Open Drain Enable Field

pub const fn set_ode(&mut self, val: SwPadCtlPadTestModeOde)

Open Drain Enable Field

pub const fn pke(&self) -> SwPadCtlPadTestModePke

Pull / Keep Enable Field

pub const fn set_pke(&mut self, val: SwPadCtlPadTestModePke)

Pull / Keep Enable Field

pub const fn pue(&self) -> SwPadCtlPadTestModePue

Pull / Keep Select Field Control signal to enable internal pull-up/down resistors or pad keeper functionality.

pub const fn set_pue(&mut self, val: SwPadCtlPadTestModePue)

Pull / Keep Select Field Control signal to enable internal pull-up/down resistors or pad keeper functionality.

pub const fn pus(&self) -> SwPadCtlPadTestModePus

Pull Up / Down Config. Field Controls signals to select pull-up or pull-down internal resistance strength.

pub const fn set_pus(&mut self, val: SwPadCtlPadTestModePus)

Pull Up / Down Config. Field Controls signals to select pull-up or pull-down internal resistance strength.

pub const fn hys(&self) -> SwPadCtlPadTestModeHys

Hyst. Enable Field

pub const fn set_hys(&mut self, val: SwPadCtlPadTestModeHys)

Hyst. Enable Field